@@ -1,18 +1,19 @@
 #!/usr/bin/perl
 use FindBin qw($Bin);
 use lib $Bin;
-use t_Common qw/oops mytempfile mytempdir/; # strict, warnings, Carp etc.
+use t_Common qw/oops/; # strict, warnings, Carp etc.
 use t_TestCommon  # Test::More etc.
          qw/$verbose $silent $debug dprint dprintf
             bug mycheckeq_literal expect1 mycheck 
             verif_no_internals_mentioned
             insert_loc_in_evalstr verif_eval_err
             arrays_eq hash_subset
-            string_to_tempfile
             @quotes/;
 use t_SSUtils;
 
-#TODO
-#
-#write something to 
-#verify that insert_rows & delete_rows updates title_rx if needed
+      #### TODO ####
+      # Write something to verify that insert_rows & delete_rows 
+      # updates title_rx if needed
+      ####
+
+# Can't warn() this because that would break the 'silence' test.
